@@ -60,6 +60,7 @@ typedef unsigned long ulong;
 #include "messages.h"
 #include "dialog.h"
 #include "offline_queue_mgmt.h"
+#include "libproxy/libproxy.h"
 
 #include "pixmaps/aim_online.xpm"
 #include "pixmaps/aim_away.xpm"
@@ -95,8 +96,8 @@ PLUGIN_INFO plugin_info = {
 	PLUGIN_SERVICE,
 	"AIM TOC",
 	"Provides AOL Instant Messenger support via the TOC protocol",
-	"$Revision: 1.58 $",
-	"$Date: 2003/12/10 10:28:54 $",
+	"$Revision: 1.61 $",
+	"$Date: 2008/08/02 06:13:09 $",
 	&ref_count,
 	plugin_init,
 	plugin_finish
@@ -293,7 +294,7 @@ static LList *eb_toc_get_smileys(void)
 	return psmileys;
 }
 
-static char * eb_aim_check_login(char * user, char * pass)
+static char * eb_aim_check_login(const char * user, const char * pass)
 {
 	return NULL;
 }
@@ -373,7 +374,7 @@ static void eb_aim_join_ack(toc_conn * conn, char * id, char * name)
 
 	strncpy( ecr->id, id , sizeof(ecr->id));
 
-	eb_join_chat_room(ecr);
+	eb_join_chat_room(ecr, TRUE);
 }
 
 static void eb_aim_join_error(toc_conn * conn, char * name)
@@ -721,7 +722,6 @@ static int eb_aim_query_connected(eb_account * account)
 static void eb_aim_accept_invite( eb_local_account * account, void * invitation )
 {
 	char * id = invitation;
-	eb_chat_room * chat_room = find_chat_room_by_id( id );
 
 	struct eb_aim_local_account_data * alad = 
 						account->protocol_local_account_data;
@@ -771,7 +771,7 @@ static eb_chat_room * eb_aim_make_chat_room(char * name, eb_local_account * acco
 	ecr->fellows = NULL;
 	ecr->connected = FALSE;
 	ecr->local_user = account;
-	eb_join_chat_room(ecr);
+	eb_join_chat_room(ecr, TRUE);
 	
 
 	return ecr;
@@ -859,7 +859,7 @@ static void ay_toc_connect_status(const char *msg, void *data)
 }
 
 
-static int eb_aim_async_socket(char *host, int port, void *cb, void *data)
+static int eb_aim_async_socket(const char *host, int port, void *cb, void *data)
 {
   int tag = proxy_connect_host(host, port, cb, data, (void *)ay_toc_connect_status);
   
@@ -963,7 +963,7 @@ static void eb_aim_logged_in (toc_conn *conn)
 }
 
 static void eb_aim_send_invite( eb_local_account * account, eb_chat_room * room,
-						 char * user, char * message)
+						 char * user, const char * message)
 {
 	struct eb_aim_local_account_data * alad;
 	alad = (struct eb_aim_local_account_data *)account->protocol_local_account_data;
@@ -1176,7 +1176,7 @@ static void eb_aim_set_current_state( eb_local_account * account, int state )
 
 }
 
-static void eb_aim_set_away(eb_local_account * account, char * message)
+static void eb_aim_set_away(eb_local_account * account, char * message, int away)
 {
 	struct eb_aim_local_account_data * alad;
 	alad = (struct eb_aim_local_account_data *)account->protocol_local_account_data;
