@@ -146,8 +146,11 @@ int JCremoveConn(JABBER_Conn *JConn)
 	{
 		if(JConn==current)
 		{
-			last->next=current->next;
-			free(current);
+			if(last != current)
+				last->next=current->next;
+			else
+				Connections = current->next;
+			g_free(current);
 			return(0);
 		}
 		last=current;
@@ -220,6 +223,12 @@ int JABBER_Login(char *handle, char *passwd, char *host, char *connect_server, i
 	char server[256], *ptr=NULL;
 	JABBER_Conn *JConn=NULL;
 
+	/* If a different connect server is not specified then atleast connect to the default */
+	if( !strcmp(connect_server, "") ) {
+		eb_debug(DBG_JBR, "connect_server is BLANK!\n\n");
+		strcpy(connect_server, host);
+	}
+
 	eb_debug(DBG_JBR,  "%s %s %i\n", handle, host, port);
 	/* Make sure the name is correct, support all formats
 	 * handle	become handle@host/ayttm
@@ -536,7 +545,7 @@ int JABBER_LeaveChatRoom(JABBER_Conn *JConn, char *room_name, char *nick)
 void JABBER_Send_typing (JABBER_Conn *JConn, const char *from, const char *to, int typing)
 {
 	char buffer[4096];
-	if (!JConn->conn) 
+	if (!JConn || !JConn->conn) 
 		return;
 	
 	if (typing) {
@@ -826,11 +835,14 @@ void j_on_packet_handler(jconn conn, jpacket packet) {
 						xmlnode_put_attrib(x, "id", "Roster");
 						jab_send (conn, x);
 						xmlnode_free(x);
-						eb_debug (DBG_JBR, "requesting agent list\n");
-						x = jutil_iqnew (JPACKET__GET, NS_AGENTS);
-						xmlnode_put_attrib(x, "id", "Agent List");
-						jab_send (conn, x);
-						xmlnode_free(x);
+
+						// Looks like this is deprecated
+//						eb_debug (DBG_JBR, "requesting agent list\n");
+//						x = jutil_iqnew (JPACKET__GET, NS_AGENTS);
+//						xmlnode_put_attrib(x, "id", "Agent List");
+//						jab_send (conn, x);
+//						xmlnode_free(x);
+
 						eb_debug(DBG_JBR,  "<Requested roster and agent list\n");
 						return;
 					}
