@@ -136,8 +136,8 @@ PLUGIN_INFO plugin_info =
 	PLUGIN_SERVICE,
 	"Yahoo",
 	"Provides Yahoo Instant Messenger support",
-	"$Revision: 1.89 $",
-	"$Date: 2004/01/07 05:28:44 $",
+	"$Revision: 1.95 $",
+	"$Date: 2007/08/03 20:38:40 $",
 	&ref_count,
 	plugin_init,
 	plugin_finish,
@@ -274,7 +274,7 @@ static int reload_prefs()
 #define YAHOO_FONT_SIZE "size=\""
 
 #ifndef FREE
-#define FREE(x)	if(x) { g_free((void *)x); x=NULL; }
+#define FREE(x)	if(x) { g_free((void *)x); x=(void *)NULL; }
 #endif
 
 typedef struct {
@@ -773,6 +773,14 @@ static void ext_yahoo_got_buddies(int id, YList * buds)
 	eb_account *ea = NULL;
 	int changed = 0;
 
+	eb_debug(DBG_MOD, "Got buddies from yahoo\n");
+
+	/* This happens when I sign off immediately after signing in */
+	if(!ela || !ela->connected) {
+		LOG(("Service Disconnected"));
+		return;
+	}
+
 	for(; buds; buds=buds->next) {
 		struct yahoo_buddy *bud = buds->data;
 		char *contact_name;
@@ -832,6 +840,12 @@ static void ext_yahoo_got_ignore(int id, YList * ign)
 	eb_account *ea = NULL;
 	int changed = 0;
 
+	/* This happens when I sign off immediately after signing in */
+	if(!ela || !ela->connected) {
+		LOG(("Service Disconnected"));
+		return ;
+	}
+
 	for(; ign; ign = ign->next) {
 		struct yahoo_buddy *bud = ign->data;
 		char *contact_name;
@@ -1048,7 +1062,7 @@ static void eb_yahoo_accept_file(gpointer data, int result)
 
 		LOG(("yahoo told us file is: %s\n", filepath));
 		if(do_prompt_save_file)
-			ay_do_file_selection(filepath, _("Save file as"), eb_yahoo_save_file, yftd);
+			ay_do_file_selection_save(filepath, _("Save file as"), eb_yahoo_save_file, yftd);
 		else
 			eb_yahoo_save_file(filepath, yftd);
 
@@ -1234,9 +1248,10 @@ static void ext_yahoo_conf_userleave(int id, char *who, char *room)
 	for(l = ycrd->members; l; l=l->next) {
 		char * handle = l->data;
 		if(!strcmp(handle, who)) {
+			YList *yl = (YList *)l;
 			ycrd->members = y_list_remove_link(ycrd->members, l);
 			FREE(handle);
-			FREE((YList *)l);
+			FREE(yl);
 			break;
 		}
 	}
@@ -1418,7 +1433,7 @@ static void ext_yahoo_conf_message(int id, char *who, char *room, char *msg, int
 	}
 	umsg[j]='\0';
 
-	eb_chat_room_show_message(chat_room, who, umsg);
+	eb_chat_room_show_message(chat_room, who, (char *)umsg);
 }
 
 static void eb_yahoo_send_chat_room_message(eb_chat_room * room, char * message)
@@ -1486,7 +1501,7 @@ static void eb_yahoo_leave_chat_room(eb_chat_room * room)
 	yahoo_conference_logoff(ycrd->id, ylad->act_id, ycrd->members, ycrd->room);
 }
 
-static void eb_yahoo_send_invite(eb_local_account * ela, eb_chat_room * ecr, char *who, char *message)
+static void eb_yahoo_send_invite(eb_local_account * ela, eb_chat_room * ecr, char *who, const char *message)
 {
 	eb_yahoo_chat_room_data *ycrd;
 	eb_yahoo_local_account_data *ylad;
@@ -2304,9 +2319,9 @@ static void ext_yahoo_login_response(int id, int succ, char *url)
 	ylad = ela->protocol_local_account_data;
 
 	if(succ == YAHOO_LOGIN_OK) {
+		ylad->status = yahoo_current_status(id);
 		ela->connecting = 0;
 		ela->connected = 1;
-		ylad->status = yahoo_current_status(id);
 
 		ay_activity_bar_update_label(ylad->connect_progress_tag, _("Fetching buddies..."));
 		is_setting_state = 1;
@@ -2422,6 +2437,7 @@ static void eb_yahoo_logout(eb_local_account * ela)
 
 	ylad->status = YAHOO_STATUS_OFFLINE;
 	ylad->id = 0;
+	ylad->act_id = NULL;
 	free_yahoo_local_account(ylad, 0);
 
 	ref_count--;
@@ -2571,14 +2587,16 @@ static LList *eb_yahoo_get_states()
 	return states;
 }
 
-static char * eb_yahoo_check_login(char * user, char * pass)
+static char * eb_yahoo_check_login(const char * user, const char * pass)
 {
-	char *s = strchr(user, '@');
-	if(s) {
-		char ret[1024];
-		snprintf(ret, sizeof(ret), _("Yahoo logins do NOT have the %s part."), s);
-		return strdup(ret);
-	}
+	// Allow @ in yahoo usernames as well. See Feature Request #959812
+//	char *s = strchr(user, '@');
+//	if(s) {
+//		char ret[1024];
+//		snprintf(ret, sizeof(ret), _("Yahoo logins do NOT have the %s part."), s);
+//		return strdup(ret);
+//	}
+
 	return NULL;
 }
 
@@ -2973,18 +2991,18 @@ static void eb_yahoo_set_idle(eb_local_account * ela, int idle)
 	LOG(("eb_yahoo_set_idle: %d", idle));
 
 	ylad = ela->protocol_local_account_data;
-	if (idle == 0 && eb_yahoo_get_current_state(ela) == YAHOO_STATUS_IDLE) {
+	if (idle == 0 && eb_yahoo_get_current_state(ela) == EB_DISPLAY_YAHOO_IDLE) {
 		if (ela->status_menu) {
 			eb_set_active_menu_status(ela->status_menu, EB_DISPLAY_YAHOO_ONLINE);
 		}
-	} else if ((idle >= 600) && (eb_yahoo_get_current_state(ela) == YAHOO_STATUS_AVAILABLE)) {
+	} else if ((idle >= 600) && (eb_yahoo_get_current_state(ela) == EB_DISPLAY_YAHOO_ONLINE)) {
 		if (ela->status_menu) {
 			eb_set_active_menu_status(ela->status_menu, EB_DISPLAY_YAHOO_IDLE);
 		}
 	}
 }
 
-static void eb_yahoo_set_away(eb_local_account * ela, char * message)
+static void eb_yahoo_set_away(eb_local_account * ela, char * message, int away)
 {
 	eb_yahoo_local_account_data *ylad;
 
@@ -3031,17 +3049,19 @@ static void eb_yahoo_set_away(eb_local_account * ela, char * message)
 				state=EB_DISPLAY_YAHOO_NOTATHOME;
 
 			FREE(lmsg);
-			ylad->away = 1;
+			ylad->away = away;
 		}
 
 		if(state == EB_DISPLAY_YAHOO_CUSTOM) {
 			LOG(("Custom away message"));
 			FREE(ylad->status_message);
 			ylad->status_message = strdup(message);
-			ylad->away = 1;
+			ylad->away = away;
 		} 
 		
-		if (ela->status_menu)
+		if(state == EB_DISPLAY_YAHOO_CUSTOM && ylad->status == YAHOO_STATUS_CUSTOM)
+			yahoo_set_away(ylad->id, YAHOO_STATUS_CUSTOM, ylad->status_message, ylad->away);
+		else if (ela->status_menu)
 			eb_set_active_menu_status(ela->status_menu, state);
 	}
 }
@@ -3215,7 +3235,7 @@ static int ext_yahoo_add_handler(int id, int fd, yahoo_input_condition cond, voi
 	return d->tag;
 }
 
-static void ext_yahoo_remove_handler(int tag)
+static void ext_yahoo_remove_handler(int id, int tag)
 {
 	YList * l;
 	for(l = handlers; l; l = l->next)
@@ -3251,8 +3271,10 @@ static void yahoo_init_smileys()
 	psmileys=add_protocol_smiley(psmileys, ">:)", "devil");
 	psmileys=add_protocol_smiley(psmileys, ">:-)", "devil");
 
-	psmileys=add_protocol_smiley(psmileys, "=:-)", "alien");
-	psmileys=add_protocol_smiley(psmileys, "=:)", "alien");
+	psmileys=add_protocol_smiley(psmileys, "=:-)", "bug");
+	psmileys=add_protocol_smiley(psmileys, "=:)", "bug");
+
+	psmileys=add_protocol_smiley(psmileys, ">-)", "alien");
 
 	psmileys=add_protocol_smiley(psmileys, "8-}", "silly");
 
@@ -3266,11 +3288,14 @@ static void yahoo_init_smileys()
 
 	psmileys=add_protocol_smiley(psmileys, "=P~", "drooling");
 
-	psmileys=add_protocol_smiley(psmileys, "(:|", "tired");
+	psmileys=add_protocol_smiley(psmileys, "(:|", "yawn");
 
 	psmileys=add_protocol_smiley(psmileys, "o:)", "angel");
 	psmileys=add_protocol_smiley(psmileys, "O:)", "angel");
 	psmileys=add_protocol_smiley(psmileys, "0:)", "angel");
+	psmileys=add_protocol_smiley(psmileys, "o:-)", "angel");
+	psmileys=add_protocol_smiley(psmileys, "O:-)", "angel");
+	psmileys=add_protocol_smiley(psmileys, "0:-)", "angel");
 
 	psmileys=add_protocol_smiley(psmileys, ":((", "cry");
 	psmileys=add_protocol_smiley(psmileys, ":-((", "cry");
@@ -3279,6 +3304,7 @@ static void yahoo_init_smileys()
 	psmileys=add_protocol_smiley(psmileys, ":-))", "biglaugh");
 
 	psmileys=add_protocol_smiley(psmileys, ":*", "kiss");
+	psmileys=add_protocol_smiley(psmileys, ":-*", "kiss");
 
 	psmileys=add_protocol_smiley(psmileys, ":o)", "clown");
 	psmileys=add_protocol_smiley(psmileys, ":O)", "clown");
@@ -3287,18 +3313,20 @@ static void yahoo_init_smileys()
 
 	psmileys=add_protocol_smiley(psmileys, "*-:)", "lightbulb");
 
-	psmileys=add_protocol_smiley(psmileys, ":)", "smile");	
-	psmileys=add_protocol_smiley(psmileys, ":-)", "smile");
-
 	psmileys=add_protocol_smiley(psmileys, ":(", "sad");	
 	psmileys=add_protocol_smiley(psmileys, ":-(", "sad");
 
+	psmileys=add_protocol_smiley(psmileys, ";))", "heehee");	
+
 	psmileys=add_protocol_smiley(psmileys, ";;)", "eyelash");	
 	psmileys=add_protocol_smiley(psmileys, ";;-)", "eyelash");
 
 	psmileys=add_protocol_smiley(psmileys, ";)", "wink");	
 	psmileys=add_protocol_smiley(psmileys, ";-)", "wink");
 
+	psmileys=add_protocol_smiley(psmileys, "\\:d/", "dancing");
+	psmileys=add_protocol_smiley(psmileys, "\\:D/", "dancing");
+
 	psmileys=add_protocol_smiley(psmileys, ":D", "grin");	
 	psmileys=add_protocol_smiley(psmileys, ":-D", "grin");
 	psmileys=add_protocol_smiley(psmileys, ":d", "grin");
@@ -3314,11 +3342,23 @@ static void yahoo_init_smileys()
 	psmileys=add_protocol_smiley(psmileys, ":b", "glasses");
 	psmileys=add_protocol_smiley(psmileys, ":-b", "glasses");
 
+	psmileys=add_protocol_smiley(psmileys, "#:S", "whew");
+	psmileys=add_protocol_smiley(psmileys, "#:-S", "whew");
+	psmileys=add_protocol_smiley(psmileys, "#:s", "whew");
+	psmileys=add_protocol_smiley(psmileys, "#:-s", "whew");
+
+	psmileys=add_protocol_smiley(psmileys, ":SS", "nail_biting");
+	psmileys=add_protocol_smiley(psmileys, ":-SS", "nail_biting");
+	psmileys=add_protocol_smiley(psmileys, ":ss", "nail_biting");
+	psmileys=add_protocol_smiley(psmileys, ":-ss", "nail_biting");
+
 	psmileys=add_protocol_smiley(psmileys, ":S", "worried");
 	psmileys=add_protocol_smiley(psmileys, ":-S", "worried");
 	psmileys=add_protocol_smiley(psmileys, ":s", "worried");
 	psmileys=add_protocol_smiley(psmileys, ":-s", "worried");
 
+	psmileys=add_protocol_smiley(psmileys, ">:/", "bring_it");
+
 	psmileys=add_protocol_smiley(psmileys, ":/", "confused");
 	psmileys=add_protocol_smiley(psmileys, ":-/", "confused");
 
@@ -3345,6 +3385,9 @@ static void yahoo_init_smileys()
 	psmileys=add_protocol_smiley(psmileys, ":-o", "oh");
 	psmileys=add_protocol_smiley(psmileys, ":-O", "oh");
 
+	psmileys=add_protocol_smiley(psmileys, "~:>", "chicken");	
+	psmileys=add_protocol_smiley(psmileys, "~o)", "coffee");	
+
 	psmileys=add_protocol_smiley(psmileys, ":>", "heyyy");	
 	psmileys=add_protocol_smiley(psmileys, ":->", "heyyy");
 
@@ -3372,6 +3415,8 @@ static void yahoo_init_smileys()
 
 	psmileys=add_protocol_smiley(psmileys, "[-(", "flying");
 
+	psmileys=add_protocol_smiley(psmileys, "[-x", "shame");
+
 	psmileys=add_protocol_smiley(psmileys, ":@)", "pig");
 
 	psmileys=add_protocol_smiley(psmileys, "8-|", "rolling_eyes");
@@ -3384,7 +3429,66 @@ static void yahoo_init_smileys()
 
 	psmileys=add_protocol_smiley(psmileys, "**==", "usflag");
 
+	psmileys=add_protocol_smiley(psmileys, "%%-", "luck");
 	psmileys=add_protocol_smiley(psmileys, "@};-", "rose");
+
+	psmileys=add_protocol_smiley(psmileys, ">:D<", "hugs");
+
+	psmileys=add_protocol_smiley(psmileys, "=((", "broken_heart");
+
+	psmileys=add_protocol_smiley(psmileys, "l-)", "loser");
+	psmileys=add_protocol_smiley(psmileys, "L-)", "loser");
+
+	psmileys=add_protocol_smiley(psmileys, "<:-p", "party");
+	psmileys=add_protocol_smiley(psmileys, "<:-P", "party");
+
+	psmileys=add_protocol_smiley(psmileys, "@-)", "hypnotised");
+
+	psmileys=add_protocol_smiley(psmileys, ":^o", "liar");
+	psmileys=add_protocol_smiley(psmileys, ":^O", "liar");
+
+	psmileys=add_protocol_smiley(psmileys, ":w", "waiting");
+	psmileys=add_protocol_smiley(psmileys, ":W", "waiting");
+	psmileys=add_protocol_smiley(psmileys, ":-w", "waiting");
+	psmileys=add_protocol_smiley(psmileys, ":-W", "waiting");
+
+	psmileys=add_protocol_smiley(psmileys, ":-<", "sigh");
+	psmileys=add_protocol_smiley(psmileys, ":<", "sigh");
+
+	psmileys=add_protocol_smiley(psmileys, ">:p", "phbbbt");
+	psmileys=add_protocol_smiley(psmileys, ">:P", "phbbbt");
+
+	psmileys=add_protocol_smiley(psmileys, "=))", "rotfl");
+
+	psmileys=add_protocol_smiley(psmileys, ":-\"", "whistle");
+
+	psmileys=add_protocol_smiley(psmileys, "b-(", "black_eye");
+
+	psmileys=add_protocol_smiley(psmileys, ":)>-", "peace");
+
+	psmileys=add_protocol_smiley(psmileys, ":-\"", "whistling");
+
+	psmileys=add_protocol_smiley(psmileys, "(%)", "yinyang");
+
+	psmileys=add_protocol_smiley(psmileys, "(*)", "star");
+
+	psmileys=add_protocol_smiley(psmileys, ":-@", "sore_ears");
+
+	psmileys=add_protocol_smiley(psmileys, "^:)^", "not_worthy");
+
+	psmileys=add_protocol_smiley(psmileys, ":-j", "just_kidding");
+
+	psmileys=add_protocol_smiley(psmileys, ":)", "smile");	
+	psmileys=add_protocol_smiley(psmileys, ":-)", "smile");
+
+	psmileys=add_protocol_smiley(psmileys, ":-l", "frustrated");
+	psmileys=add_protocol_smiley(psmileys, "[-o<", "praying");
+	psmileys=add_protocol_smiley(psmileys, "$-)", "money_eyes");
+
+	psmileys=add_protocol_smiley(psmileys, "o->", "hiro");
+	psmileys=add_protocol_smiley(psmileys, "o=>", "billy");
+	psmileys=add_protocol_smiley(psmileys, "o-+", "april");
+
 }
 
 static LList *eb_yahoo_get_smileys(void)
